@@ -516,6 +516,14 @@ class TestLuaRuntime(SetupLuaRuntimeMixin, unittest.TestCase):
             raise ValueError("huhu")
         self.assertRaises(ValueError, function, test)
 
+
+class TestPythonObjectsInLua(SetupLuaRuntimeMixin, unittest.TestCase):
+    def test_explicit_python_function(self):
+        lua_func = self.lua.eval('function(func) return table.foreach({ab="cd"}, python.as_function(func)) end')
+        def join(*args):
+            return '-'.join(args)
+        self.assertEqual('ab-cd', lua_func(join))
+
     def test_type_conversion(self):
         lua_type = self.lua.eval('type')
         self.assertEqual('number', lua_type(1))
@@ -549,6 +557,51 @@ class TestLuaRuntime(SetupLuaRuntimeMixin, unittest.TestCase):
         self.assertEqual('userdata', lua_type(GetAttr()))
         self.assertNotEqual(None, lua_get_index(GetAttr()))
 
+    def test_pylist(self):
+        getitem = self.lua.eval('function(L, i) return L[i] end')
+        self.assertEqual(3, getitem([1,2,3], 2))
+
+    def test_python_iter_list(self):
+        values = self.lua.eval('''
+            function(L)
+                local t = {}
+                local i = 1
+                for value in python.iter(L) do
+                    t[i] = value
+                    i = i+1
+                end
+                return t
+            end
+        ''')
+        self.assertEqual([1,2,3], list(values([1,2,3])))
+
+    def test_python_enumerate_list(self):
+        values = self.lua.eval('''
+            function(L)
+                local t = {}
+                for index, value in python.enumerate(L) do
+                    t[index+1] = value
+                end
+                return t
+            end
+        ''')
+        self.assertEqual([1,2,3], list(values([1,2,3])))
+
+    def test_python_iter_dict_items(self):
+        values = self.lua.eval('''
+            function(d)
+                local t = {}
+                for key, value in python.iterex(d.items()) do
+                    t[key] = value
+                end
+                return t
+            end
+        ''')
+        table = values(lupa.as_attrgetter(dict(a=1, b=2, c=3)))
+        self.assertEqual(1, table['a'])
+        self.assertEqual(2, table['b'])
+        self.assertEqual(3, table['c'])
+
 
 class TestLuaCoroutines(SetupLuaRuntimeMixin, unittest.TestCase):
     def test_coroutine_iter(self):
@@ -1222,21 +1275,21 @@ class TestFastRLock(unittest.TestCase):
         b.wait_for_finished()
         self.assertEqual(len(b.finished), N)
 
-    def test_with(self):
-        lock = self.locktype()
-        def f():
-            lock.acquire()
-            lock.release()
-        def _with(err=None):
-            with lock:
-                if err is not None:
-                    raise err
-        _with()
-        # Check the lock is unacquired
-        self.Bunch(f, 1).wait_for_finished()
-        self.assertRaises(TypeError, _with, TypeError)
-        # Check the lock is unacquired
-        self.Bunch(f, 1).wait_for_finished()
+    ## def test_with(self):
+    ##     lock = self.locktype()
+    ##     def f():
+    ##         lock.acquire()
+    ##         lock.release()
+    ##     def _with(err=None):
+    ##         with lock:
+    ##             if err is not None:
+    ##                 raise err
+    ##     _with()
+    ##     # Check the lock is unacquired
+    ##     self.Bunch(f, 1).wait_for_finished()
+    ##     self.assertRaises(TypeError, _with, TypeError)
+    ##     # Check the lock is unacquired
+    ##     self.Bunch(f, 1).wait_for_finished()
 
     def test_thread_leak(self):
         # The lock shouldn't leak a Thread instance when used from a foreign
